Struct ColumnInfo
pub struct ColumnInfo {
pub name: String,
pub col_type: ColumnType,
pub null: bool,
pub is_identity: bool,
pub collation: Option<Collation>,
pub default: Option<ColumnDefault>,
pub comment: Option<String>,
}Fields
name: StringThe name of the column
col_type: ColumnTypeThe type of the column with additional definitions, e.g. precision, length
null: boolCan this column contains null
is_identity: boolIs the identity property set
collation: Option<Collation>The unique name for the collation if the column is character data or text data type
default: Option<ColumnDefault>Default value expression for this column, if any
comment: Option<String>Column comment
Implementations
impl ColumnInfo
impl ColumnInfo
pub fn write(&self) -> ColumnDef
pub fn write_col_type(&self, col_def: ColumnDef) -> ColumnDef