Struct NumericAttr
pub struct NumericAttr {
pub precision: Option<u32>,
pub scale: Option<u32>,
}Fields
precision: Option<u32>The maximum total number of decimal digits to be stored.
scale: Option<u32>The number of decimal digits that are stored to the right of the decimal point. This number is subtracted from p to determine the maximum number of digits to the left of the decimal point.